# pygame template
import pygame
from pygame.locals import (
    K_ESCAPE,
    KEYDOWN,
    QUIT,
    MOUSEBUTTONDOWN
)

from box import Box, LockableBox, BoxFullError, BoxIsLockedError


pygame.init()

pygame.font.init()
error_font = pygame.font.SysFont("Arial", 15)


WIDTH = 640//2
HEIGHT = 480//2
SIZE = (WIDTH, HEIGHT)

screen = pygame.display.set_mode(SIZE)
clock = pygame.time.Clock()

# ---------------------------
# Initialize global variables

# my_box = Box(50, 50, 4)  # x, y, max_capacity
# lock_box = LockableBox(200, 50, 6)
boxes = [
    Box(50, 50, 4),
    LockableBox(200, 50, 6)
]
# ---------------------------

running = True
while running:
    # EVENT HANDLING
    for event in pygame.event.get():
        if event.type == KEYDOWN:
            if event.key == K_ESCAPE:
                running = False
        elif event.type == QUIT:
            running = False
        elif event.type == MOUSEBUTTONDOWN:
            mouse_location = event.pos
            for box in boxes:
                if box.is_clicked(mouse_location):
                    if event.button == 1:  # left-click
                        try:
                            box.add_item(1)
                        except BoxFullError:
                            print("The box is full!")
                        except BoxIsLockedError:
                            print("The box is locked!")
                    elif event.button == 3:  # right-click
                        if type(box) is LockableBox:
                            box.toggle_lock()
    
    # GAME STATE UPDATES
    # All game math and comparisons happen here

    # DRAWING
    screen.fill((255, 255, 255))  # always the first drawing command

    for box in boxes:
        box.draw(screen)

    # Must be the last two lines
    # of the game loop
    pygame.display.flip()
    clock.tick(30)
    #---------------------------


pygame.quit()

